@@ -18,7 +18,7 @@ use constant VELO_INC  => 10; # volume change offset
 
 my $input_name   = shift || 'tempopad'; # midi controller device
 my $output_name  = shift || 'fluid';    # fluidsynth
-my $filter_names = shift || '';         # chord,delay,pedal,offset
+my $filter_names = shift || '';         # delay,pedal,drums
 
 my @filter_names = split /\s*,\s*/, $filter_names;
 
@@ -120,12 +120,6 @@ sub drum_parts ($note) {
 sub drums ($event) {
     my ($ev, $channel, $note, $vel) = $event->@*;
     return 1 unless $ev eq 'note_on';
-    # my @notes = (PEDAL, $note, $note + 7);
-    # my $delay_time = 0;
-    # for my $n (@notes) {
-        # $delay_time += $delay;
-        # delay_send($delay_time, [ $ev, $channel, $n, $vel ]);
-    # }
     my $part = drum_parts($note);
     my $d = MIDI::Drummer::Tiny->new(bpm => 100);
     MIDI::RtMidi::ScorePlayer->new(
@@ -135,7 +129,7 @@ sub drums ($event) {
       parts    => [ $part ],
       sleep    => 0,
       infinite => 0,
-      dump     => 1,
+      # dump     => 1,
     )->play_async->retain;
     return 1;
 }
