@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use Moo;
 use strictures 2;
@@ -149,13 +149,20 @@ MIDI::RtController - Control your MIDI controller
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
   use MIDI::RtController ();
 
-  my $rtc = MIDI::RtController->new(verbose => 1);
+  my $rtc = MIDI::RtController->new(
+    input  => 'input-MIDI-device',
+    output => 'output-MIDI-device',
+  );
+
+  # add stuff to the $rtc->loop
+
+  $rtc->run;
 
 =head1 DESCRIPTION
 
@@ -186,7 +193,7 @@ Return the MIDI B<output> port.
 
   $loop = $rtc->loop;
 
-Return the L<IO::Async::Loop>..
+Return the L<IO::Async::Loop>.
 
 =head1 METHODS
 
@@ -202,13 +209,13 @@ Create a new C<MIDI::RtController> object.
 
   $rtc->send_it($event);
 
-Send a MIDI event to the output port.
+Send a MIDI B<event> to the output port.
 
 =head2 delay_send
 
   $rtc->delay_send($delay_time, $event);
 
-Send a MIDI event to the output port when the B<delay_time> expires.
+Send a MIDI B<event> to the output port when the B<delay_time> expires.
 
 =head2 run
 
@@ -218,9 +225,21 @@ Run the B<loop>!
 
 =head1 SEE ALSO
 
-L<Moo>
+The F<eg/*.pl> program(s)
 
-L<http://somewhere.el.se>
+L<Future::AsyncAwait>
+
+L<IO::Async::Channel>
+
+L<IO::Async::Loop>
+
+L<IO::Async::Routine>
+
+L<IO::Async::Timer::Countdown>
+
+L<MIDI::RtMidi::FFI::Device>
+
+L<Moo>
 
 =head1 AUTHOR
 
